AFRL annotation helper functions (sarpy.annotation.afrl)
========================================================

.. automodule:: sarpy.annotation.afrl
    :members:
    :show-inheritance:
    :inherited-members:
